@@ -11,8 +11,9 @@ from gerrit.utils.exceptions import UnsupportMethod
 
 class GerritAccount(BaseModel):
     def __init__(self, **kwargs):
-        super(GerritAccount, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.entity_name = "username"
+        self.endpoint = f"/accounts/{self.username}"
 
     def get_name(self):
         """
@@ -20,11 +21,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/name" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.get(base_url)
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get_endpoint_url(self.endpoint + "/name")
 
     def set_name(self, input_):
         """
@@ -43,17 +40,12 @@ class GerritAccount(BaseModel):
 
 
         :param input_: the AccountNameInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#account-name-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #account-name-input
         :return:
         """
-        endpoint = "/accounts/%s/name" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-
-        return result
+        return self.gerrit.put(self.endpoint + "/name",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def delete_name(self):
         """
@@ -63,8 +55,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/name" % self.username
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + "/name")
 
     def get_status(self):
         """
@@ -76,10 +67,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/status" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/status")
 
     def set_status(self, status):
         """
@@ -88,14 +76,9 @@ class GerritAccount(BaseModel):
         :param status: account status
         :return:
         """
-        endpoint = "/accounts/%s/status" % self.username
         input_ = {"status": status}
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/status",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def set_username(self, input_):
         """
@@ -113,17 +96,12 @@ class GerritAccount(BaseModel):
             result = account.set_username(input_)
 
         :param input_: the UsernameInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#username-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #username-input
         :return:
         """
-        endpoint = "/accounts/%s/username" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-
-        return result
+        return self.gerrit.put(self.endpoint + "/username",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def set_displayname(self, input_):
         """
@@ -140,21 +118,16 @@ class GerritAccount(BaseModel):
             result = account.set_displayname(input_)
 
         :param input_: the DisplayNameInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#display-name-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #display-name-input
         :return:
         """
         version = self.gerrit.version
         if parse(version) < parse("3.2.0"):
             raise UnsupportMethod("The server does not support this method")
 
-        endpoint = "/accounts/%s/displayname" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-
-        return result
+        return self.gerrit.put(self.endpoint + "/displayname",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def get_active(self):
         """
@@ -162,10 +135,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/active" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/active")
 
     def set_active(self):
         """
@@ -173,8 +143,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/active" % self.username
-        self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.put(self.endpoint + "/active")
 
     def delete_active(self):
         """
@@ -183,8 +152,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/active" % self.username
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + "/active")
 
     def set_http_password(self, input_):
         """
@@ -201,16 +169,12 @@ class GerritAccount(BaseModel):
             result = account.set_http_password(input_)
 
         :param input_: the HttpPasswordInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#http-password-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #http-password-input
         :return:
         """
-        endpoint = "/accounts/%s/password.http" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/password.http",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def delete_http_password(self):
         """
@@ -218,21 +182,18 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/password.http" % self.username
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + "/password.http")
 
     def get_oauth_token(self):
         """
         Returns a previously obtained OAuth access token.
-        If there is no token available, or the token has already expired, '404 Not Found' is returned as response.
+        If there is no token available, or the token has already expired, '404 Not Found' is
+        returned as response.
         Requests to obtain an access token of another user are rejected with '403 Forbidden'.
 
         :return:
         """
-        endpoint = "/accounts/%s/oauthtoken" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/oauthtoken")
 
     @property
     def emails(self):
@@ -252,10 +213,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/capabilities" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/capabilities")
 
     def check_capability(self, capability):
         """
@@ -264,10 +222,7 @@ class GerritAccount(BaseModel):
         :param capability:
         :return:
         """
-        endpoint = "/accounts/%s/capabilities/%s" % (self.username, capability)
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + f"/capabilities/{capability}")
 
     @property
     def groups(self):
@@ -276,9 +231,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/groups" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + "/groups")
         return [self.gerrit.groups.get(item.get("id")) for item in result]
 
     def get_avatar(self):
@@ -287,10 +240,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/avatar" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/avatar")
 
     def get_avatar_change_url(self):
         """
@@ -298,10 +248,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/avatar.change.url" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/avatar.change.url")
 
     def get_user_preferences(self):
         """
@@ -309,10 +256,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/preferences" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/preferences")
 
     def set_user_preferences(self, input_):
         """
@@ -338,16 +282,12 @@ class GerritAccount(BaseModel):
             result = account.set_user_preferences(input_)
 
         :param input_: the PreferencesInput entity，
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#preferences-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #preferences-input
         :return:
         """
-        endpoint = "/accounts/%s/preferences" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/preferences",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def get_diff_preferences(self):
         """
@@ -355,10 +295,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/preferences.diff" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/preferences.diff")
 
     def set_diff_preferences(self, input_):
         """
@@ -385,16 +322,12 @@ class GerritAccount(BaseModel):
             result = account.set_diff_preferences(input_)
 
         :param input_: the DiffPreferencesInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#diff-preferences-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #diff-preferences-input
         :return:
         """
-        endpoint = "/accounts/%s/preferences.diff" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/preferences.diff",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def get_edit_preferences(self):
         """
@@ -402,10 +335,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/preferences.edit" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/preferences.edit")
 
     def set_edit_preferences(self, input_):
         """
@@ -434,16 +364,12 @@ class GerritAccount(BaseModel):
             result = account.set_edit_preferences(input_)
 
         :param input_: the EditPreferencesInfo entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#edit-preferences-info
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #edit-preferences-info
         :return:
         """
-        endpoint = "/accounts/%s/preferences.edit" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/preferences.edit",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def get_watched_projects(self):
         """
@@ -451,10 +377,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/watched.projects" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/watched.projects")
 
     def modify_watched_projects(self, input_):
         """
@@ -478,13 +401,8 @@ class GerritAccount(BaseModel):
         :param input_: the ProjectWatchInfo entities as list
         :return:
         """
-        endpoint = "/accounts/%s/watched.projects" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/watched.projects",
+                                json=input_, headers=self.gerrit.default_headers)
 
     def delete_watched_projects(self, input_):
         """
@@ -505,30 +423,25 @@ class GerritAccount(BaseModel):
         :param input_: the watched projects as list
         :return:
         """
-        endpoint = "/accounts/%s/watched.projects:delete" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
+        self.gerrit.post(self.endpoint + "/watched.projects:delete",
+                         json=input_, headers=self.gerrit.default_headers)
 
     def get_external_ids(self):
         """
         Retrieves the external ids of a user account.
-        Only external ids belonging to the caller may be requested. Users that have Modify Account can request external
+        Only external ids belonging to the caller may be requested.
+        Users that have Modify Account can request external
         ids that belong to other accounts.
 
         :return:
         """
-        endpoint = "/accounts/%s/external.ids" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/external.ids")
 
     def delete_external_ids(self, input_):
         """
         Delete a list of external ids for a user account.
-        Only external ids belonging to the caller may be deleted. Users that have Modify Account can delete external
-        ids that belong to other accounts.
+        Only external ids belonging to the caller may be deleted. Users that have Modify Account
+        can delete external ids that belong to other accounts.
 
         .. code-block:: python
 
@@ -542,11 +455,8 @@ class GerritAccount(BaseModel):
         :param input_: the external ids as list
         :return:
         """
-        endpoint = "/accounts/%s/external.ids:delete" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
+        self.gerrit.post(self.endpoint + "/external.ids:delete",
+                         json=input_, headers=self.gerrit.default_headers)
 
     def list_contributor_agreements(self):
         """
@@ -554,10 +464,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/agreements" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/agreements")
 
     def sign_contributor_agreement(self, input_):
         """
@@ -572,16 +479,13 @@ class GerritAccount(BaseModel):
             result = account.sign_contributor_agreement(input_)
 
         :param input_: the ContributorAgreementInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#contributor-agreement-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #contributor-agreement-input
         :return:
         """
-        endpoint = "/accounts/%s/agreements" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/agreements",
+                               json=input_, headers=self.gerrit.default_headers)
+
 
     def delete_draft_comments(self, input_):
         """
@@ -596,16 +500,12 @@ class GerritAccount(BaseModel):
             result = account.delete_draft_comments(input_)
 
         :param input_: the DeleteDraftCommentsInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#delete-draft-comments-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
+          #delete-draft-comments-input
         :return:
         """
-        endpoint = "/accounts/%s/drafts:delete" % self.username
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/drafts:delete",
+                                json=input_, headers=self.gerrit.default_headers)
 
     def index(self):
         """
@@ -613,8 +513,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/index" % self.username
-        self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.post(self.endpoint + "/index")
 
     def get_default_starred_changes(self):
         """
@@ -622,9 +521,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/starred.changes" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + "/starred.changes")
         return [self.gerrit.changes.get(item.get("id")) for item in result]
 
     def put_default_star_on_change(self, id_):
@@ -634,8 +531,7 @@ class GerritAccount(BaseModel):
         :param id_: change id
         :return:
         """
-        endpoint = "/accounts/%s/starred.changes/%s" % (self.username, id_)
-        self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.put(self.endpoint + f"/starred.changes/{id_}")
 
     def remove_default_star_from_change(self, id_):
         """
@@ -644,8 +540,7 @@ class GerritAccount(BaseModel):
         :param id_: change id
         :return:
         """
-        endpoint = "/accounts/%s/starred.changes/%s" % (self.username, id_)
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + f"/starred.changes/{id_}")
 
     def get_starred_changes(self):
         """
@@ -653,9 +548,7 @@ class GerritAccount(BaseModel):
 
         :return:
         """
-        endpoint = "/accounts/%s/stars.changes" % self.username
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + "/stars.changes")
         return [self.gerrit.changes.get(item.get("id")) for item in result]
 
     def get_star_labels_from_change(self, id_):
@@ -665,10 +558,7 @@ class GerritAccount(BaseModel):
         :param id_: change id
         :return:
         """
-        endpoint = "/accounts/%s/stars.changes/%s" % (self.username, id_)
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + f"/stars.changes/{id_}")
 
     def update_star_labels_on_change(self, id_, input_):
         """
@@ -691,10 +581,5 @@ class GerritAccount(BaseModel):
           https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#stars-input
         :return:
         """
-        endpoint = "/accounts/%s/stars.changes/%s" % (self.username, id_)
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + f"/stars.changes/{id_}",
+                                json=input_, headers=self.gerrit.default_headers)
